[![Build Status](https://travis-ci.org/NSLS-II/ophyd.svg)](https://travis-ci.org/NSLS-II/ophyd)

[![Code Health](https://landscape.io/github/NSLS-II/ophyd/master/landscape.svg?style=flat)](https://landscape.io/github/NSLS-II/ophyd/master)

Ophyd - EPICS Client Abstractions
=================================

[Documentation](http://nsls-ii.github.io/ophyd/)

## Conda Recipes

Install the most recent tagged build: `conda install ophyd -c lightsource2-tag`

Install the most recent tagged build: `conda install ophyd -c lightsource2-dev`

Find the tagged recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-tag/ophyd) and the dev recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-dev/ophyd)
